Changelog
=========

0.2.2 (2022)
------------------
- Change JSON output


0.2.1 (2022)
------------------
- Fix KeyErrors for auxilary data


0.2.0 (2022)
------------------
- Change return types for parsers (breaking)
- Add partial support for DC energy meter mode on SmartShunt


0.1.0 (2022)
------------------
- Add basic data parsing for SmartShunt
